diff projects/oscillator_bank/render.cpp @ 56:3c3a1357657d newapi

Further API update to name three primary functions setup(), render() and cleanup(). Changed include paths so now can #include <BeagleRT.h>. Removed stale pru_rtaudio.bin file as this is now done as pru_rtaudio_bin.h. Updated examples to new API and fixed minor compiler warnings along the way. Network example needs further attention to compile.
author andrewm
date Wed, 15 Jul 2015 12:10:51 +0100
parents a6d223473ea2
children ac8eb07afcf5
line wrap: on
line diff
--- a/projects/oscillator_bank/render.cpp	Mon Jun 15 18:16:00 2015 +0100
+++ b/projects/oscillator_bank/render.cpp	Wed Jul 15 12:10:51 2015 +0100
@@ -6,8 +6,8 @@
  */
 
 
-#include "../../include/BeagleRT.h"
-#include "../../include/Utilities.h"
+#include <BeagleRT.h>
+#include <Utilities.h>
 #include <rtdk.h>
 #include <cstdlib>
 #include <cmath>
@@ -34,7 +34,7 @@
 
 // These settings are carried over from main.cpp
 // Setting global variables is an alternative approach
 // to passing a structure to userData in initialise_render()
 
 extern int gNumOscillators;
 extern int gWavetableLength;
@@ -50,7 +50,7 @@
 							  float *lookupTable);
 }
 
 // initialise_render() is called once before the audio rendering starts.
 // Use it to perform any initialisation and allocation which is dependent
 // on the period size or sample rate.
 //
@@ -58,7 +58,7 @@
 // in from the call to initAudio().
 //
 // Return true on success; returning false halts the program.
-bool initialise_render(BeagleRTContext *context, void *userData)
+bool setup(BeagleRTContext *context, void *userData)
 {
 	srandom(time(NULL));
 
@@ -207,10 +207,10 @@
 }
 
 
 // cleanup_render() is called once at the end, after the audio has stopped.
 // Release any resources that were allocated in initialise_render().
 
-void cleanup_render(BeagleRTContext *context, void *userData)
+void cleanup(BeagleRTContext *context, void *userData)
 {
 	free(gWavetable);
 	free(gPhases);
@@ -34,7 +34,7 @@
 // These settings are carried over from main.cpp
 // Setting global variables is an alternative approach
-// to passing a structure to userData in initialise_render()
+// to passing a structure to userData in setup()
 
 extern int gNumOscillators;
@@ -50,7 +50,7 @@
 }
 
-// initialise_render() is called once before the audio rendering starts.
+// setup() is called once before the audio rendering starts.
 // Use it to perform any initialisation and allocation which is dependent
 // on the period size or sample rate.
@@ -207,10 +207,10 @@
 
 
-// cleanup_render() is called once at the end, after the audio has stopped.
-// Release any resources that were allocated in initialise_render().
+// cleanup() is called once at the end, after the audio has stopped.
+// Release any resources that were allocated in setup().
 